import {AppsV1Api} from "@kubernetes/client-node";
import {kc} from "./kubeConfig";
import {hostname} from "os";
import {V1DeploymentStatus} from "@kubernetes/client-node/dist/gen/model/v1DeploymentStatus";
import {getIngress} from "./ingress";
import isPortReachable from "./utils";

const hostnameString = hostname();
const stringToCheck = 'zeroscale'
const devMode = !hostnameString.includes(stringToCheck)
console.log(`running ${devMode ? 'in dev mode' : 'in prod mode'} because host ${hostnameString} does ${devMode ? 'not ' : ''}include "${stringToCheck}"`)

const apps = kc.makeApiClient(AppsV1Api);

async function patch(deployment: string, replicas: number) {
    console.log('scaling', deployment, 'to', replicas)
    if(!devMode) return apps.patchNamespacedDeployment(deployment, 'default', [{
        op: 'replace',
        path: '/spec/replicas',
        value: replicas,
    }],undefined, undefined, undefined, undefined, undefined, { headers: { 'content-type': 'application/json-patch+json' }})
}

export async function enable(deployment: string) {
    return patch(deployment, 1);
}
export async function disable(deployment: string) {
    return patch(deployment, 0);
}

export async function status(deployment: string): Promise<V1DeploymentStatus> {
    const ingress=getIngress(deployment);
    if(!ingress) throw new Error('Autoscaling not enabled on service.');
    const response = await apps.readNamespacedDeployment(ingress[0].name, 'default');
    return response.body.status!;
}
export async function isOnline(deployment: string): Promise<boolean> {
    const ingress=getIngress(deployment);
    if(!ingress) throw new Error('Autoscaling not enabled on service.');
    console.log(ingress[0])
    return await isPortReachable(ingress[0].name, ingress[0].port, 250);
}
