import {AppsV1Api} from "@kubernetes/client-node";
import {kc} from "./kubeConfig";
import {parseTime} from "./utils";

const apps = kc.makeApiClient(AppsV1Api);

type DeploymentInfo = {
    timeout: number,
    running: boolean,
    dependencies: string[],
}
let deployments: {[key: string]: DeploymentInfo} = {}

async function parseDeployments() {
    const readDeployments= await apps.listNamespacedDeployment('default')
    const mapped = readDeployments.body.items
        .filter(deployment=>deployment.metadata!.labels?.zeroscale)
        .map(deployment => {
            const name = deployment.metadata!.name!;
            const running = deployment.status!.replicas! > 0;
            const timeout = parseTime(deployment.metadata!.labels!.zeroscale)!
            const dependencies = deployment.metadata!.labels!.zeroscaleDependencies?.split(',') ?? []
            return [name, {timeout, running, dependencies}]
        })
    deployments = Object.fromEntries(mapped)
    return deployments;
}
setInterval(parseDeployments, 60000);
export const initDeployments = parseDeployments();

export function getDeploymentInfo(deployment: string): DeploymentInfo | undefined {
    return deployments[deployment];
}
