import {PassThrough} from "stream";
import {CoreV1Api, Log} from "@kubernetes/client-node";
import {kc} from "./kubeConfig";
import {parseTime} from "./utils";
import {system} from "./systems/system";
const log = new Log(kc);
const core = kc.makeApiClient(CoreV1Api);
const timeoutSetting = parseTime(process.env.TIMEOUT || '5s')*1000
let lastMessageTime=0

async function getPodName(): Promise<string>  {
    const readPods= await core.listNamespacedPod(system.traefikNamespace, undefined, undefined, undefined, undefined, 'app.kubernetes.io/name=traefik')
    const podNames=readPods.body.items
        .filter(pod=>pod.status!.phase=='Running')
        .map(pod=>({time: +pod.metadata!.creationTimestamp!, name: pod.metadata!.name}))
        .sort((first,second)=>first.time-second.time)
        .map(item=>item.name)
        .reverse();
    if(podNames.length==0) throw new Error('no traefik pods found');
    console.log('podName', podNames[0]);
    return podNames[0]!;
}

//Assuming ingress name is the same as deployment name, which isn't required!
let isInitial=true;
let timeout=setTimeout(()=>{});
const logStream = new PassThrough();
export function addListener(listener: (chunk: string) => void) {
    logStream.on('data', listener);
}
addListener(()=>lastMessageTime=+new Date());
export function startLog() {
    startLogInstance()
    setInterval(()=>{
        if(lastMessageTime+timeoutSetting<+new Date()) startLogInstance();
    }, 1000)
}
let globalRequest: Awaited<ReturnType<typeof log['log']>> | undefined;
async function startLogInstance() {
    if(!isInitial) console.log('timeout');
    const podName=await getPodName();
    if(globalRequest) globalRequest.abort();
    log.log(system.traefikNamespace, podName, 'traefik', logStream, {
        follow: true,
        pretty: false,
        timestamps: false,
        tailLines: isInitial?0:undefined,
        sinceSeconds: isInitial?undefined:timeoutSetting+5, //give it a little extra time, just in case
    }).then(request=>{
        globalRequest=request;
    })
    isInitial=false;
}
