import {getDeploymentInfo, initDeployments} from "./deployments";
import {disable, enable} from "./deploymentManager";
import {Service} from "./ingress";

const timeouts: {[key: string]: ReturnType<typeof setTimeout>} = {}
export function markVisited(service: Service | string) {
    if(typeof service === 'string') service = {name: service, port: -1};
    const deployment = service.name;
    const deploymentInfo = getDeploymentInfo(deployment)
    if(deploymentInfo == undefined) return;
    deploymentInfo.dependencies.forEach(dependency => {
        markVisited(dependency);
    })
    if (timeouts[deployment]) clearTimeout(timeouts[deployment]);
    else enable(deployment);
    timeouts[deployment] = setTimeout(() => {
        disable(deployment);
        delete timeouts[deployment];
    }, deploymentInfo.timeout*1000);
}
function logTimeouts() {
    console.log('deployments', Object.keys(timeouts));
}
setInterval(logTimeouts, 60000);
initDeployments.then(deployments => {
    for(let deployment in deployments) {
        if(deployments[deployment].running) markVisited(deployment)
    }
    logTimeouts();
})
