import express, { Express, Request, Response } from 'express';
import {status, isOnline} from './deploymentManager';
import cors from 'cors';
import {getIngress} from "./ingress";
import {markVisited} from "./markVisited";

const app: Express = express();
const port = 8080;

app.use(cors())
app.get('/api/enable/:hostname', async (req: Request, res: Response) => {
    const ingress = getIngress(req.params.hostname)
    if(!ingress) return res.status(400).json({error: 'Autoscaling not enabled on service.'});
    ingress.forEach(markVisited);
    return res.json(true);
});

app.get('/api/deployment/:deployment', async (req: Request, res: Response) => {
    let currentStatus;
    try {
        currentStatus = await status(req.params.deployment);
    } catch(e: any) {
        if(e.body) {
            console.log(e.body)
            return res.status(400).json({error: e.body});
        }
        console.log(e)
        return res.status(500).json({error: e.message});
    }
    return res.json(currentStatus);
});
app.get('/api/deployment/:deployment/online', async (req: Request, res: Response) => {
    let online;
    try {
        online = await isOnline(req.params.deployment);
    } catch(e: any) {
        if(e.body) {
            console.log(e.body)
            return res.status(400).json({error: e.body});
        }
        console.log(e)
        return res.status(500).json({error: e.message});
    }
    return res.json(online);
})
app.get('/', (req: Request, res: Response) => {
    res.json(true)
});

export function startServer() {
    app.listen(port, () => {
        console.log(`⚡️[server]: Server is running at http://localhost:${port}`);
    });
}
