import {getIngress, Service} from "../ingress";
import {System} from "./system";

type logLine = {
    RequestAddr?: string,
    'request_User-Agent'?: string,
}
export class MicroK8s implements System {
    lineReceived(chunk: string): Service[] | undefined {
        let line: logLine
        try {
            line = JSON.parse(chunk)
        } catch (e) {
            console.log('error parsing log line', e, Buffer.from(chunk).toString());
            return;
        }
        if (!line.RequestAddr) {
            console.log('no RequestAddr!', line, Buffer.from(chunk).toString());
            return;
        }
        const userAgent = line['request_User-Agent']
        if(userAgent && userAgent.includes('Uptime-Kuma')) return; //ignore Uptime-Kuma.
        const deployments = getIngress(line.RequestAddr)
        if (!deployments) return;
        return deployments;
    }
    traefikNamespace = 'traefik';
}
