import {getIngress, Service} from "../ingress";
import {System} from "./system";

type logLine = {
    time: string,
    Request?: string,
    level: string,
    msg: string
}
type Request = {
    Method: string,
    URL: {
        Scheme: string,
        Opaque: string,
        User: string,
        Host: string,
        Path: string,
        RawPath: string,
        OmitHost: boolean,
        ForceQuery: boolean,
        RawQuery: string,
        Fragment: string,
        RawFragment: string,
    },
    Proto: string,
    ProtoMajor: number,
    ProtoMinor: number,
    Header: { [key: string]: string[] },
    ContentLength: number,
    TransferEncoding?: string[], //not sure about type, was null. this was auto-suggested by copilot
    Host: string,
    Form?: any, //not sure about type, was null
    PostForm?: any, //not sure about type, was null
    MultipartForm?: any, //not sure about type, was null
    Trailer?: any, //not sure about type, was null
    RemoteAddr: string,
    RequestURI: string,
    TLS: any, //not sure about type, was null
}
export class K3s implements System {
    lineReceived(chunk: string): Service[] | undefined {
        let line: logLine
        try {
            line = JSON.parse(chunk)
        } catch (e) {
            console.log('error parsing log line', e, Buffer.from(chunk).toString());
            return;
        }
        if (!line.Request) {
            if (line.msg == 'mime: no media type') return; //TODO other project... fix this.
            if (line.msg == 'Caught HTTP Status Code 503, returning error page') return; // Custom error page for disabled services.
            if (line.msg.includes(' certificate')) return; //TODO make this more specific
            //console.log('no Request!', line, Buffer.from(chunk).toString());
            return;
        }
        const request: Request = JSON.parse(line.Request)
        const userAgent = request.Header['User-Agent']
        if(userAgent && userAgent[0].includes('Uptime-Kuma')) return; //ignore Uptime-Kuma.
        const deployments = getIngress(request.Host)
        if (!deployments) return;
        return deployments;
    }
    traefikNamespace = 'kube-system';
}
