import {Socket} from 'node:net';
//parse time like "1m30s" to seconds. in this example 90.
export function parseTime(time: string): number {
    if(!isNaN(+time)) return +time; //if it's just a number, return it (seconds)
    const timeRegex = /(\d+)([smhd])/g;
    let timeInSeconds = 0;
    let match;
    while ((match = timeRegex.exec(time)) !== null) {
        const amount = parseInt(match[1]);
        const unit = match[2];
        if (unit === 's') timeInSeconds += amount;
        if (unit === 'm') timeInSeconds += amount * 60;
        if (unit === 'h') timeInSeconds += amount * 60 * 60;
        if (unit === 'd') timeInSeconds += amount * 60 * 60 * 24;
    }
    return timeInSeconds;
}

import net from 'node:net';

export default async function isPortReachable(host: string, port: number, timeout: number = 1000): Promise<boolean> {
    return new Promise(resolve => {
        const socket = new Socket();
        const onError = () => {
            socket.destroy();
            resolve(false);
        };
        socket.setTimeout(timeout);
        socket.once('error', onError);
        socket.once('timeout', onError);
        socket.connect(port, host, () => {
            socket.end();
            resolve(true);
        });
    });
}
